@@ -1,5 +1,5 @@
 """
-hook into AA
+Hook into AA
 """
 
 # Django
@@ -58,7 +58,7 @@ def register_menu():
 @hooks.register("url_hook")
 def register_urls():
     """
-    Register our basu url
+    Register our base url
     :return:
     """
 
